@@ -1,15 +1,16 @@
-#ABSTRACT: read xls / write xls 读写 xls
+#ABSTRACT: read xls / write xls
 package XLS::Simple;
 
 require Exporter;
 @ISA    = qw(Exporter);
-@EXPORT = qw(write_xls read_xls);
+@EXPORT = qw(write_xls read_xls read_xlsx);
 
-our $VERSION=0.02;
+our $VERSION=0.021;
 
 use Encode;
 use Excel::Writer::XLSX;
 use Spreadsheet::Read;
+use Spreadsheet::XLSX;
 
 use strict;
 use warnings;
@@ -67,8 +68,27 @@ sub format_xls_data {
     return $data;
 }
 
+sub read_xlsx {
+    my ($xlsx, %opt) = @_;
+    my $excel = Spreadsheet::XLSX->new($xlsx);
+    my @res;
+    for my $sheet (@{$excel->{Worksheet}}){
+        my $max_row = $sheet->{MaxRow} || $sheet->{MinRow};
+        for my $row ($sheet->{MinRow} .. $max_row){
+            my $max_col = $sheet->{MaxCol} || $sheet->{MinCol};
+            my @data = map { $sheet->{Cells}[$row][$_]{Val} } 
+            ($sheet->{MinCol} .. $max_col);
+            push @res, \@data;
+            return \@data if($opt{only_header});
+        }
+    }
+    shift @res if ( $opt{skip_header} );
+    return \@res;
+}
+
 sub read_xls {
     my ( $xls, %opt ) = @_;
+    return read_xlsx($xls, %opt) if($xls=~/\.xlsx$/i);
 
     my $workbook = ReadData($xls);
 
@@ -83,41 +103,3 @@ sub read_xls {
 }
 
 1;
-
-
-=pod
-
-=encoding utf8
-
-=head1 名称
-
-L<XLS::Simple> xls读取写入
-
-=head1 函数
-
-=begin html
-
-实例参考<a href="xt/">xt子文件夹</a>
-
-=end html
-
-=head2 write_xls
-
-写入xls
-
-    write_xls([ ['测试', '写入' ] ], 
-        'test.xlsx', 
-        header=> ['一二', '三四'], 
-        charset=>'utf8');
-
-=head2 read_xls
-
-读取xls
-
-    my $header = read_xls( 'test.xlsx', only_header => 1, );
-
-    my $data = read_xls( 'test.xlsx', skip_header => 1, );
-
-    my $all = read_xls( 'test.xlsx', );
-
-=cut
